==> lb_plus-2.2.x-dev.tar.gz: lb_plus/modules/lb_plus_edit_plus/src/Form/UpdateBlockForm.php <==
<?php

namespace Drupal\lb_plus_edit_plus\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Form\SubformState;
use Drupal\lb_plus\LbPlusFormTrait;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\layout_builder\SectionStorageInterface;
use Drupal\Core\Plugin\ContextAwarePluginInterface;
use Drupal\edit_plus_lb\Form\UpdateBlockForm as UpdateBlockFormBase;

/**
 * Extends the UpdateBlockForm to add Edit + integrations.
 */
class UpdateBlockForm extends UpdateBlockFormBase {

  use LbPlusFormTrait;
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, SectionStorageInterface $section_storage = NULL, $delta = NULL, $region = NULL, $uuid = NULL, $nested_storage_path = NULL) {
    $current_section_storage = $this->formInit($form_state, $section_storage, $nested_storage_path);
    if (empty($form_state->get('main_section_storage'))) {
      $form_state->set('main_section_storage', $section_storage);
    }
    return parent::buildForm($form, $form_state, $current_section_storage, $delta, $region, $uuid, $nested_storage_path);
  }

  /**
   * Submit handler.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Submit the plugin form.
    $subform_state = SubformState::createForSubform($form['settings'], $form, $form_state);
    $this->getPluginForm($this->block)->submitConfigurationForm($form, $subform_state);

    // If this block is context-aware, set the context mapping.
    if ($this->block instanceof ContextAwarePluginInterface) {
      $this->block->setContextMapping($subform_state->getValue('context_mapping', []));
    }

    // Get the submitted configuration.
    $configuration = $this->block->getConfiguration();

    // Update the block in the current section storage.
    $current_section_storage = $form_state->getStorage()['current_section_storage'];
    $current_section_storage->getSection($this->delta)->getComponent($this->uuid)->setConfiguration($configuration);


    // Update the parent entity section storage.
    $storage = $form_state->getStorage();
    $main_section_storage = $this->sectionStorageHandler()->updateSectionStorage($storage['main_section_storage'], $storage['nested_storage_path'], $current_section_storage);
    $storage['main_section_storage'] = $main_section_storage;
    $form_state->setStorage($storage);


    $this->messenger()->addWarning($this->t('You have unsaved changes.'));
    $form_state->setRebuild(TRUE);

    // Clear the page cache.
    Cache::invalidateTags([
      getCacheTag($this->getMainEntity($form, $form_state)),
      getCacheTag($this->getFormEntity($form, $form_state)),
    ]);
  }

  /**
   * Submission AJAX callback.
   */
  protected function successfulAjaxSubmit(array $form, FormStateInterface $form_state) {
    $response = new AjaxResponse();

    $entity = $this->getMainEntity($form, $form_state);
    $this->buildBottomBar($entity, $response);
    $this->renderMessages($response);
    $this->updateForm($response, $form, $form_state);
    $this->updatePage($response, $form, $form_state);

    return $response;
  }

  public function getMainEntity(array &$form, FormStateInterface $form_state): EntityInterface {
    $entity = $form_state->get('main_section_storage')->getContextValue('entity');
    return $entity;
  }

  protected function getComponent(&$form, FormStateInterface $form_state) {
    if (empty($form_state->get('nested_storage_path'))) {
      return parent::getComponent($form, $form_state);
    }
    // Extract the updated block content from the main entity section storage.
    $main_section_storage = $this->sectionStorageHandler->layoutBuilderTempstore->get($form_state->get('main_section_storage'));
    $layout_block_component = $this->sectionStorageHandler->getNestedComponent($main_section_storage, $form_state->get('nested_storage_path'));
    $layout_block = $this->sectionStorageHandler->getBlockContent($layout_block_component->getPlugin());

    $args = $form_state->getBuildInfo()['args'];
    $section_delta = $args[1];
    $component_uuid = $args[3];
    return $layout_block->layout_builder__layout->getSection($section_delta)->getComponent($component_uuid);
  }

}

==> lb_plus-3.0.x-dev.tar.gz: lb_plus/modules/lb_plus_edit_plus/src/Form/UpdateBlockForm.php <==
<?php

namespace Drupal\lb_plus_edit_plus\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Form\SubformState;
use Drupal\lb_plus\LbPlusFormTrait;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\layout_builder\SectionStorageInterface;
use Drupal\Core\Plugin\ContextAwarePluginInterface;
use Drupal\edit_plus_lb\Form\UpdateBlockForm as UpdateBlockFormBase;

/**
 * Extends the UpdateBlockForm to add Edit + integrations.
 */
class UpdateBlockForm extends UpdateBlockFormBase {

  use LbPlusFormTrait;
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, SectionStorageInterface $section_storage = NULL, $delta = NULL, $region = NULL, $uuid = NULL, $nested_storage_path = NULL) {
    $current_section_storage = $this->formInit($form_state, $section_storage, $nested_storage_path);
    if (empty($form_state->get('main_section_storage'))) {
      $form_state->set('main_section_storage', $section_storage);
    }
    return parent::buildForm($form, $form_state, $current_section_storage, $delta, $region, $uuid, $nested_storage_path);
  }

  /**
   * Submit handler.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Submit the plugin form.
    $subform_state = SubformState::createForSubform($form['settings'], $form, $form_state);
    $this->getPluginForm($this->block)->submitConfigurationForm($form, $subform_state);

    // If this block is context-aware, set the context mapping.
    if ($this->block instanceof ContextAwarePluginInterface) {
      $this->block->setContextMapping($subform_state->getValue('context_mapping', []));
    }

    // Get the submitted configuration.
    $configuration = $this->block->getConfiguration();

    // Update the block in the current section storage.
    $current_section_storage = $form_state->getStorage()['current_section_storage'];
    $current_section_storage->getSection($this->delta)->getComponent($this->uuid)->setConfiguration($configuration);


    // Update the parent entity section storage.
    $storage = $form_state->getStorage();
    $main_section_storage = $this->sectionStorageHandler()->updateSectionStorage($storage['main_section_storage'], $storage['nested_storage_path'], $current_section_storage);
    $storage['main_section_storage'] = $main_section_storage;
    $form_state->setStorage($storage);


//    $this->messenger()->addWarning($this->t('You have unsaved changes.'));
    $form_state->setRebuild(TRUE);

    // Clear the page cache.
    Cache::invalidateTags([
      getCacheTag($this->getMainEntity($form, $form_state)),
      getCacheTag($this->getFormEntity($form, $form_state)),
    ]);
  }

  /**
   * Submission AJAX callback.
   */
  protected function successfulAjaxSubmit(array $form, FormStateInterface $form_state) {
    $response = new AjaxResponse();

    $entity = $this->getMainEntity($form, $form_state);
    $this->buildBottomBar($entity, $response);
    $this->renderMessages($response);
    $this->updateForm($response, $form, $form_state);
    $this->updatePage($response, $form, $form_state);

    return $response;
  }

  public function getMainEntity(array &$form, FormStateInterface $form_state): EntityInterface {
    $entity = $form_state->get('main_section_storage')->getContextValue('entity');
    return $entity;
  }

  protected function getComponent(&$form, FormStateInterface $form_state) {
    if (empty($form_state->get('nested_storage_path'))) {
      return parent::getComponent($form, $form_state);
    }
    // Extract the updated block content from the main entity section storage.
    $main_section_storage = $this->sectionStorageHandler->layoutBuilderTempstore->get($form_state->get('main_section_storage'));
    $layout_block_component = $this->sectionStorageHandler->getNestedComponent($main_section_storage, $form_state->get('nested_storage_path'));
    $layout_block = $this->sectionStorageHandler->getBlockContent($layout_block_component->getPlugin());

    $args = $form_state->getBuildInfo()['args'];
    $section_delta = $args[1];
    $component_uuid = $args[3];
    return $layout_block->layout_builder__layout->getSection($section_delta)->getComponent($component_uuid);
  }

}
